Clean Insights Python SDK
=========================

This document describes how to get started using the Clean Insights SDK for
Python. 
[CleanInsights](https://cleaninsights.org) gives developers a safe,
sustainable, and secure way to gather insights about their users using cutting
edge techniques like differential privacy, onion routing, certificate pinning
and more.
